pub fn validate_structure(sig: &RingSignature) -> Result<(), RingError>Expand description
Verify the structural validity of a ring signature (not the crypto).
pub fn validate_structure(sig: &RingSignature) -> Result<(), RingError>Verify the structural validity of a ring signature (not the crypto).