pub struct RingSignature {
pub ring_members: Vec<Vec<u8>>,
pub signature: Vec<u8>,
pub signer_count: u32,
pub auditor_evidence: Option<Vec<u8>>,
}Expand description
A ring signature — anonymous signature on behalf of a ring of eligible signers.
Fields
ring_members: Vec<Vec<u8>>All eligible signers’ public keys (the “ring”).
signature: Vec<u8>The signature itself.
signer_count: u32How many ring members collaborated to produce this signature (T).
auditor_evidence: Option<Vec<u8>>Optional auditor-encrypted identity evidence.